This Readme file will have info and examples for installing, setting up, and using CADMUS/OWLEYE client.

Example:
from owleye_client import owleye_client as owleye

owleye.hello_world()
owleye.hello_world('This is an overload test')